@@ -38,7 +38,7 @@ class Simplifier:
         print(str.format(val, args))
     printf.__doc__ = "equivelant to 'print(str.format(val, *args))'"
     
-    def nthrt(self, val: float64 | int64, n: float64 | int64) -> float64 | int64:
+    def nthrt(self, val: float64 | int64, n: int64) -> float64:
         return val**(1.0/n)
     nthrt.__doc__ = "take the nth root of val"
 
